@@ -118,16 +118,14 @@ def _heat_index(temperature: np.ndarray,
 
         # adjustments
         heatindex = xr.where(
-            xr.ufuncs.logical_and(
-                relative_humidity < 13,
-                xr.ufuncs.logical_and(temperature > 80, temperature < 112)),
+            np.logical_and(relative_humidity < 13,
+                           np.logical_and(temperature > 80, temperature < 112)),
             heatindex - ((13 - relative_humidity) / 4) * np.sqrt(
                 (17 - abs(temperature - 95)) / 17), heatindex)
 
         heatindex = xr.where(
-            xr.ufuncs.logical_and(
-                relative_humidity > 85,
-                xr.ufuncs.logical_and(temperature > 80, temperature < 87)),
+            np.logical_and(relative_humidity > 85,
+                           np.logical_and(temperature > 80, temperature < 87)),
             heatindex + ((relative_humidity - 85.0) / 10.0) *
             ((87.0 - temperature) / 5.0), heatindex)
 
@@ -468,16 +466,14 @@ def _xheat_index(temperature: xr.DataArray,
 
         # adjustments
         heatindex = xr.where(
-            xr.ufuncs.logical_and(
-                relative_humidity < 13,
-                xr.ufuncs.logical_and(temperature > 80, temperature < 112)),
+            np.logical_and(relative_humidity < 13,
+                           np.logical_and(temperature > 80, temperature < 112)),
             heatindex - ((13 - relative_humidity) / 4) * np.sqrt(
                 (17 - abs(temperature - 95)) / 17), heatindex)
 
         heatindex = xr.where(
-            xr.ufuncs.logical_and(
-                relative_humidity > 85,
-                xr.ufuncs.logical_and(temperature > 80, temperature < 87)),
+            np.logical_and(relative_humidity > 85,
+                           np.logical_and(temperature > 80, temperature < 87)),
             heatindex + ((relative_humidity - 85.0) / 10.0) *
             ((87.0 - temperature) / 5.0), heatindex)
 
@@ -882,7 +878,7 @@ def relhum_ice(temperature: typing.Union[np.ndarray, list, float],
     `relhum <https://geocat-comp.readthedocs.io/en/latest/user_api/generated/geocat.comp.meteorology.relhum.html#geocat.comp.meteorology.relhum>`_,
     `_xrelhum <https://geocat-comp.readthedocs.io/en/latest/internal_api/generated/geocat.comp.meteorology._xrelhum.html#geocat.comp.meteorology._xrelhum>`_,
     `relhum_water <https://geocat-comp.readthedocs.io/en/latest/user_api/generated/geocat.comp.meteorology.relhum_water.html#geocat.comp.meteorology.relhum_water>`_,
-    `_relhum_ice <https://geocat-comp.readthedocs.io/en/latest/internal_api/generated/geocat.comp.meteorology._relhum_ice.html#geocat.comp.meteorology._relhum_ice>_
+    `_relhum_ice <https://geocat-comp.readthedocs.io/en/latest/internal_api/generated/geocat.comp.meteorology._relhum_ice.html#geocat.comp.meteorology._relhum_ice>`_
 
     Related NCL Functions:
     `relhum <https://www.ncl.ucar.edu/Document/Functions/Built-in/relhum.shtml>`_,
@@ -954,7 +950,7 @@ def relhum_water(temperature: typing.Union[np.ndarray, list, float],
     See Also
     --------
     Related GeoCAT Functions:
-    `relhum <https://geocat-comp.readthedocs.io/en/latest/user_api/generated/geocat.comp.meteorology.relhum.html#geocat.comp.meteorology.relhum>_`,
+    `relhum <https://geocat-comp.readthedocs.io/en/latest/user_api/generated/geocat.comp.meteorology.relhum.html#geocat.comp.meteorology.relhum>`_,
     `_xrelhum <https://geocat-comp.readthedocs.io/en/latest/internal_api/generated/geocat.comp.meteorology._xrelhum.html#geocat.comp.meteorology._xrelhum>`_,
     `relhum_ice <https://geocat-comp.readthedocs.io/en/latest/user_api/generated/geocat.comp.meteorology.relhum_ice.html#geocat.comp.meteorology.relhum_ice>`_,
     `relhum_water <https://geocat-comp.readthedocs.io/en/latest/internal_api/generated/geocat.comp.meteorology._relhum_water.html#geocat.comp.meteorology._relhum_water>`_
